==> qt-creator-opensource-src-4.7.2.tar.gz: qt-creator-opensource-src-4.7.2/src/plugins/projectexplorer/targetsetuppage.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "projectexplorer_export.h"

#include "kitinformation.h"
#include "kitmanager.h"
#include "projectimporter.h"

#include <utils/wizardpage.h>

#include <QPointer>
#include <QString>
#include <QMap>

QT_FORWARD_DECLARE_CLASS(QSpacerItem)

namespace Core { class Id; }
namespace Utils { class FileName; }

namespace ProjectExplorer {
class Kit;
class Project;

namespace Internal {
class ImportWidget;
class TargetSetupPageUi;
class TargetSetupWidget;
} // namespace Internal

/// \internal
class PROJECTEXPLORER_EXPORT TargetSetupPage : public Utils::WizardPage
{
    Q_OBJECT

public:
    explicit TargetSetupPage(QWidget *parent = nullptr);
    ~TargetSetupPage() override;

    /// Initializes the TargetSetupPage
    /// \note The import information is gathered in initializePage(), make sure that the right projectPath is set before
    void initializePage() override;

    // Call these before initializePage!
    void setRequiredKitPredicate(const ProjectExplorer::Kit::Predicate &predicate);
    void setPreferredKitPredicate(const ProjectExplorer::Kit::Predicate &predicate);
    void setProjectPath(const QString &dir);
    void setProjectImporter(ProjectImporter *importer);

    /// Sets whether the targetsetupage uses a scrollarea
    /// to host the widgets from the factories
    /// call this before \sa initializePage()
    void setUseScrollArea(bool b);

    bool isComplete() const override;
    bool setupProject(Project *project);
    QList<Core::Id> selectedKits() const;

    /// Overrides the summary text of the targetsetuppage
    void setNoteText(const QString &text);
    void showOptionsHint(bool show);

    void openOptions();
    void changeAllKitsSelections();

    void kitFilterChanged(const QString &filterText);

private:
    void handleKitAddition(ProjectExplorer::Kit *k);
    void handleKitRemoval(ProjectExplorer::Kit *k);
    void handleKitUpdate(ProjectExplorer::Kit *k);
    void updateVisibility();

    void kitSelectionChanged();
    static QList<Kit *> sortedKitList(const Kit::Predicate &predicate);

    bool isUpdating() const;
    void selectAtLeastOneKit();
    void removeWidget(Kit *k) { removeWidget(widget(k)); }
    void removeWidget(Internal::TargetSetupWidget *w);
    Internal::TargetSetupWidget *addWidget(Kit *k);

    void setupImports();
    void import(const Utils::FileName &path, bool silent = false);

    void setupWidgets(const QString &filterText = QString());
    void reset();

    Internal::TargetSetupWidget *widget(Kit *k, Internal::TargetSetupWidget *fallback = nullptr) const
    { return widget(k->id(), fallback); }
    Internal::TargetSetupWidget *widget(const Core::Id kitId,
                                        Internal::TargetSetupWidget *fallback = nullptr) const;

    ProjectExplorer::Kit::Predicate m_requiredPredicate;
    ProjectExplorer::Kit::Predicate m_preferredPredicate;
    QPointer<ProjectImporter> m_importer = nullptr;
    QLayout *m_baseLayout = nullptr;
    QString m_projectPath;
    QString m_defaultShadowBuildLocation;
    std::vector<Internal::TargetSetupWidget *> m_widgets;
    Internal::TargetSetupWidget *m_firstWidget = nullptr;

    Internal::TargetSetupPageUi *m_ui;

    Internal::ImportWidget *m_importWidget;
    QSpacerItem *m_spacer;
    QList<QWidget *> m_potentialWidgets;

    bool m_forceOptionHint = false;
    bool m_widgetsWereSetUp = false;
};

} // namespace ProjectExplorer

==> qt-creator-opensource-src-15.0.1.tar.gz: qt-creator-opensource-src-15.0.1/src/plugins/projectexplorer/targetsetuppage.h <==
// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0

#pragma once

#include "projectexplorer_export.h"

#include "kit.h"

#include <utils/wizardpage.h>

namespace Utils { class FilePath; }

namespace ProjectExplorer {
class Kit;
class Project;
class ProjectImporter;

namespace Internal { class TargetSetupPagePrivate; }

/// \internal
class PROJECTEXPLORER_EXPORT TargetSetupPage : public Utils::WizardPage
{
    Q_OBJECT

public:
    explicit TargetSetupPage(QWidget *parent = nullptr);
    ~TargetSetupPage() override;

    /// Initializes the TargetSetupPage
    /// \note The import information is gathered in initializePage(), make sure that the right projectPath is set before
    void initializePage() override;

    // Call these before initializePage!
    void setTasksGenerator(const TasksGenerator &tasksGenerator);
    void setProjectPath(const Utils::FilePath &dir);
    void setProjectImporter(ProjectImporter *importer);
    bool importLineEditHasFocus() const;

    /// Sets whether the targetsetupage uses a scrollarea
    /// to host the widgets from the factories
    /// call this before \sa initializePage()
    void setUseScrollArea(bool b);

    bool isComplete() const override;
    bool setupProject(Project *project);
    QList<Utils::Id> selectedKits() const;

    void openOptions();
    void changeAllKitsSelections();

private:
    void showEvent(QShowEvent *event) final;

    Internal::TargetSetupPagePrivate *d;
};

} // namespace ProjectExplorer
